@@ -7,12 +7,14 @@
 //! Please read the [crate documentation](crate) for more information and examples.
 
 mod parse;
+mod parse_error;
 mod parser_column;
 mod parser_state;
 mod tree;
 
 pub use parse::earley;
 pub use parse::parse;
+pub use parse_error::ParseError;
 pub use parser_column::ParserColumn;
-pub(crate) use parser_state::ParserState;
+pub use parser_state::ParserState;
 pub use tree::Tree;
